/*
   SWTを利用したサンプルです。

   set????? メソッドで画面上に置くボタンの場所やイベントなどを設定しています。

*/
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.widgets.*;
import org.eclipse.swt.*;
import java.lang.*;


public class SwtSample
{
	static Shell sh;
	static MessageBox confirmBox;

	/* マウスダウン／マウスアップ テストボタン */
	public static void setUpDownButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 10, 380, 20);
		btn.setText("マウスのボタンを押したり話したりしてください。");

		btn.addMouseListener(new MouseAdapter()
		{
			public void mouseDown(MouseEvent e)
			{
				btn.setText("マウスボタンが押されています。");
			}

			public void mouseUp(MouseEvent e)
			{
				btn.setText("マウスボタンが放されました。");
			}
		}
		);
	}

	/* ダブルクリック テストボタン */
	public static void setDoubleClickButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 40, 380, 20);
		btn.setText("ダブルクリックを試してください。");

		btn.addMouseListener(new MouseAdapter()
		{
			public void mouseDoubleClick(MouseEvent e)
			{
				btn.setText("ダブルクリック成功");	
			}
		}
		);
	}

	/* マウスムーブ テストボタン */
	public static void setMouseMoveButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 70, 380, 20);
		btn.setText("ボタンの上でマウスカーソルを動かしてください。");

		btn.addMouseMoveListener(new MouseMoveListener()
		{
			public void mouseMove(MouseEvent e)
			{
				String label = new String("X:" + String.valueOf(e.x) + " , Y:" + String.valueOf(e.y) + "");
				btn.setText(label);
			}
		}						 
		);
	}

	/* マウスイン／マウスアウト テストボタン */
	public static void setInOutButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 100, 380, 20);
		btn.setText("ボタンにカーソルを合わせたり離したりしてください。");

		btn.addMouseTrackListener(new MouseTrackAdapter()
		{
			public void mouseEnter(MouseEvent e)
			{
				btn.setText("カーソルが領域内に入りました。");	
			}
			public void mouseExit(MouseEvent e)
			{
				btn.setText("カーソルが領域外にでました。");	
			}
		}
		);
	}

	/* テスト用メッセージボックス呼び出しボタン */
	public static void setCallMsgBoxButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 130, 380, 20);
		btn.setText("メッセージボックスを呼び出します。");

		btn.addMouseListener(new MouseAdapter()
		{
			public void mouseUp(MouseEvent e)
			{
				MessageBox mb = new MessageBox(sh, SWT.ICON_INFORMATION | SWT.YES | SWT.NO);
				mb.setText("Dialog");
				mb.setMessage("好きなボタンを押してください。");
				switch (mb.open()) {
					case SWT.YES :
						mb.setMessage("「はい」が押されました。");
						break;
					case SWT.NO :
						mb.setMessage("「いいえ」が押されました。");
						break;
					default :
						break;
				}
				mb.open();
			}
		}
		);
	}
	
	/* ファイル保存ダイアログ呼び出しボタン */
	public static void setCallFileDialogButton()
	{
		final Button btn = new Button(sh, SWT.PUSH|SWT.CENTER);
		btn.setBounds(10, 160, 380, 20);
		btn.setText("ファイルオープンダイアログを開きます。");

		btn.addMouseListener(new MouseAdapter()
		{
			public void mouseUp(MouseEvent e)
			{
				/* Style: SAVE OPEN MULTI */
				FileDialog fd = new FileDialog(sh, SWT.MULTI);
				fd.setText("STYLE:SWT.MULTI");
				String resData = fd.open();
				confirmBox.setText("選ばれたファイル");
				if (resData != null) {
					confirmBox.setMessage(resData);
				} else {
					confirmBox.setMessage("キャンセルされました。");
				}
				confirmBox.open();
			}
		}
		);
	}

	/* TabFolder設置 */
	public static void setTabFolder()
	{
		TabFolder tf = new TabFolder(sh, 0);
		TabItem ti1 = new TabItem(tf, 0);
		ti1.setText("Item1");
		TabItem ti2 = new TabItem(tf, 0);
		ti2.setText("Item2");
		tf.setBounds(10, 190, 380, 100);

		Composite cs = new Composite(tf, 0);
		ti1.setControl(cs);

		Button tstbtn = new Button(cs, SWT.PUSH|SWT.CENTER);
		
		tstbtn.setText("タブ切替確認のためのボタン");
		tstbtn.setBounds(10, 10, 160, 20);
	}

	/* Main */
	public static void main(String args[])
	{
		Display disp = new Display();
		sh = new Shell(disp);

		sh.setText("Window");
		sh.setSize(410, 325);
		sh.open();

		/* メッセージ表示用のメッセージボックス */
		confirmBox = new MessageBox(sh, SWT.ICON_INFORMATION | SWT.OK);
		
		/* TabFolder配置 */
		setTabFolder();

		/* Button配置 */
		setUpDownButton();
		setDoubleClickButton();
		setMouseMoveButton();
		setInOutButton();
		setCallMsgBoxButton();
		setCallFileDialogButton();

		while (!sh.isDisposed()) {
			if (!disp.readAndDispatch()) {
				disp.sleep();
			}
		}
		disp.dispose();
	}
}
